.. :changelog:

History
-------

0.1.0 (2019-04-04)
++++++++++++++++++

* Development version

0.1.0 (2020-04-06)
++++++++++++++++++

* First version on TestPyPI

0.2.0 (2020-05-14)
++++++++++++++++++

* Completely moved all cosmological computation to astropy
* support for continuous (not tabulated) redshift distribution
* Run external test with established pipeline
* Extended tests for lensing weights